DataVisualization
=================

.. automodule:: smltk.datavisualization
    :no-members:

.. autosummary::
    :nosignatures:

    smltk.datavisualization.DataVisualization

Features management
-------------------

.. autosummary::
    :nosignatures:

    smltk.datavisualization.DataVisualization.get_df
    smltk.datavisualization.DataVisualization.get_inference_df

Images management
-----------------

.. autosummary::
    :nosignatures:

    smltk.datavisualization.DataVisualization.get_inference_objects
    smltk.datavisualization.DataVisualization.get_inference_objects_df
    smltk.datavisualization.DataVisualization.plot_inference_objects

Detailed list
-------------

.. autoclass:: smltk.datavisualization.DataVisualization
    :members:
